@@ -1,4 +1,5 @@
-import camera_calibration.honeycomb
+import camera_calibration.analyze
+import honeycomb_io
 import cv_utils
 import video_io
 import pandas as pd
@@ -171,7 +172,7 @@ def prepare_colmap_inputs(
         os.makedirs(output_directory, exist_ok=True)
         shutil.copy2(source_path, output_path)
         # Fetch camera position
-        position = camera_calibration.honeycomb.fetch_device_position(
+        position = honeycomb_io.fetch_device_position(
             device_id=camera_device_id,
             datetime=image_timestamp,
             client=client,
@@ -224,6 +225,68 @@ def prepare_colmap_inputs(
                 )
                 shutil.copy2(source_path, output_path)
 
+def generate_image_info_file(
+    calibration_directory=None,
+    calibration_identifier=None,
+    image_info_path=None,
+    environment_id=None,
+    environment_name=None,
+    default_image_timestamp=None,
+    default_camera_type=None,
+    chunk_size=100,
+    client=None,
+    uri=None,
+    token_uri=None,
+    audience=None,
+    client_id=None,
+    client_secret=None
+):
+    # Set output directory and path
+    if image_info_path is None:
+        if calibration_directory is None or calibration_identifier is None:
+            raise ValueError('Must specify either image info path or calibration directory and calibration identifier')
+        output_directory = os.path.join(
+            calibration_directory,
+            calibration_identifier
+        )
+        image_info_path = os.path.join(
+            output_directory,
+            'image_info.csv'
+        )
+    else:
+        output_directory = os.path.dirname(os.path.normpath(image_info_path))
+    if default_image_timestamp is None:
+        default_image_timestamp = datetime.datetime.now(tz=datetime.timezone.utc)
+    camera_info_df = honeycomb_io.fetch_camera_info(
+        environment_id=environment_id,
+        environment_name=environment_name,
+        start=default_image_timestamp,
+        end=default_image_timestamp,
+        chunk_size=chunk_size,
+        client=client,
+        uri=uri,
+        token_uri=token_uri,
+        audience=audience,
+        client_id=client_id,
+        client_secret=client_secret
+    )
+    image_info_df = (
+        camera_info_df
+        .reindex(columns=[
+            'device_name',
+            'part_number'
+        ])
+        .rename(columns={
+            'device_name': 'camera_name',
+            'part_number': 'camera_type'
+        })
+    )
+    if default_camera_type is not None:
+        image_info_df['camera_type'] = default_camera_type
+    image_info_df['image_timestamp'] = default_image_timestamp.isoformat()
+    os.makedirs(output_directory, exist_ok=True)
+    image_info_df.to_csv(image_info_path)
+
 def fetch_colmap_output_data_local(
     calibration_directory=None,
     calibration_identifier=None,
@@ -372,13 +435,13 @@ def fetch_colmap_image_data_local(
         else None
     ).astype('string')
     logger.info('Attempting to extract camera device IDs from image names')
-    df['device_id'] = df['image_name'].apply(camera_calibration.honeycomb.extract_honeycomb_id).astype('object')
+    df['device_id'] = df['image_name'].apply(honeycomb_io.extract_honeycomb_id).astype('object')
     device_ids = df['device_id'].dropna().unique().tolist()
     logger.info('Found {} device IDs among image names'.format(
         len(device_ids)
     ))
     logger.info('Fetching camera names')
-    camera_names = camera_calibration.honeycomb.fetch_camera_names(
+    camera_names = honeycomb_io.fetch_camera_names(
         camera_ids=device_ids,
         chunk_size=chunk_size,
         client=client,
@@ -600,7 +663,7 @@ def compare_colmap_calibration_to_existing(
         .to_dict(orient='index')
     )
     device_ids = list(new_calibrations.keys())
-    old_calibrations = camera_calibration.honeycomb.fetch_camera_calibrations(
+    old_calibrations = honeycomb_io.fetch_camera_calibrations(
         camera_ids=device_ids,
         start=existing_calibration_time,
         end=existing_calibration_time
@@ -673,7 +736,7 @@ def write_colmap_output_honeycomb(
         ))
     colmap_output_df = colmap_output_df.dropna(subset=['device_id'])
     calibration_start = pd.to_datetime(calibration_start, utc=True).to_pydatetime()
-    intrinsic_calibration_ids = camera_calibration.honeyomb.write_intrinsic_calibration_data(
+    intrinsic_calibration_ids = honeycomb_io.write_intrinsic_calibration_data(
         data=colmap_output_df,
         start_datetime=calibration_start,
         client=client,
@@ -683,7 +746,7 @@ def write_colmap_output_honeycomb(
         client_id=client_id,
         client_secret=client_secret
     )
-    extrinsic_calibration_ids = camera_calibration.honeycomb.write_extrinsic_calibration_data(
+    extrinsic_calibration_ids = honeycomb_io.write_extrinsic_calibration_data(
         data=colmap_output_df,
         start_datetime=calibration_start,
         coordinate_space_id=coordinate_space_id,
@@ -694,7 +757,7 @@ def write_colmap_output_honeycomb(
         client_id=client_id,
         client_secret=client_secret
     )
-    position_assignment_ids = camera_calibration.honeycomb.write_position_data(
+    position_assignment_ids = honeycomb_io.write_position_data(
         data=colmap_output_df,
         start_datetime=calibration_start,
         coordinate_space_id=coordinate_space_id,
